@@ -2,18 +2,17 @@
 
 
 package HiD::App;
-$HiD::App::VERSION = '1.91';
+$HiD::App::VERSION = '1.95';
 use Moose;
 extends 'MooseX::App::Cmd';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 sub default_command { 'help' };
 
@@ -36,7 +35,7 @@ See C<perldoc hid> for usage information.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
