@@ -2,18 +2,17 @@
 
 
 package HiD::App::Command;
-$HiD::App::Command::VERSION = '1.91';
+$HiD::App::Command::VERSION = '1.95';
 use Moose;
 extends 'MooseX::App::Cmd::Command';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use HiD;
 
@@ -133,7 +132,7 @@ stored configuration information, and return it.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
