@@ -2,18 +2,17 @@
 
 
 package HiD::App::Command::config;
-$HiD::App::Command::config::VERSION = '1.91';
+$HiD::App::Command::config::VERSION = '1.95';
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 sub _run {
   my( $self , $opts , $args ) = @_;
@@ -68,7 +67,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
