@@ -2,20 +2,19 @@
 
 
 package HiD::App::Command::init;
-$HiD::App::Command::init::VERSION = '1.91';
+$HiD::App::Command::init::VERSION = '1.95';
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use YAML::XS qw/ DumpFile /;
+use YAML::Tiny;
 
 
 has blog => (
@@ -62,9 +61,8 @@ EOF
 
   $self->_init_blog if $self->blog;
 
-  DumpFile( '_config.yml' , {
-    title => $self->title ,
-  });
+  my $yaml = YAML::Tiny->new({ title => $self->title });
+  $yaml->write( '_config.yml' );
 
   say "Enjoy your new site!";
 }
@@ -149,7 +147,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
