@@ -2,33 +2,30 @@
 
 
 package HiD::File;
-$HiD::File::VERSION = '1.91';
+$HiD::File::VERSION = '1.95';
 use Moose;
 with 'HiD::Role::IsPublished';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename         qw/ fileparse /;
-use File::Copy::Recursive  qw/ fcopy /;
-use File::Path             qw/ make_path /;
-use Path::Class            qw/ file / ;
+use Path::Tiny;
 
 
 sub publish {
   my $self = shift;
 
-  my( undef , $dir ) = fileparse( $self->output_filename );
+  my $out = path( $self->output_filename );
+  my $dir = $out->parent;
 
-  make_path $dir unless -d $dir;
+  $dir->mkpath unless $dir->is_dir;
 
-  fcopy( $self->input_filename , $self->output_filename )
+  path( $self->input_filename )->copy( $out )
     or die $!;
 }
 
@@ -73,7 +70,7 @@ well if you're trying to figure out how an object from this class works.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
