@@ -2,15 +2,16 @@
 
 
 package HiD::Generator;
-$HiD::Generator::VERSION = '1.91';
+$HiD::Generator::VERSION = '1.95';
 use Moose::Role;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
-use feature    qw/ unicode_strings /;
+
+use Path::Tiny;
 
 requires 'generate';
 
@@ -18,11 +19,12 @@ requires 'generate';
 sub _create_destination_directory_if_needed {
   my( $self , $dest ) = @_;
 
-  if ( -e $dest ) {
-    $self->FATAL( "'$dest' exists and is not a directory!" )
-      unless -d $dest;
-  }
-  else { mkdir $dest }
+  $dest = path( $dest );
+
+  $self->FATAL( "'$dest' exists and is not a directory!" )
+    if $dest->is_file;
+
+  $dest->mkpath;
 
   return 1;
 }
@@ -61,7 +63,7 @@ $site->posts >> and so on.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
