@@ -2,16 +2,17 @@
 
 
 package HiD::Generator::AtomFeed;
-$HiD::Generator::AtomFeed::VERSION = '1.91';
+$HiD::Generator::AtomFeed::VERSION = '1.95';
 use Moose;
 with 'HiD::Generator';
 
+use 5.014; # strict, unicode_strings
+
 use DateTime;
+use XML::Feed;
+use XML::Feed::Entry;
+
 use HiD::VirtualPage;
-use XML::Atom::Entry;
-use XML::Atom::Feed;
-use XML::Atom::Link;
-use XML::Atom::Person;
 
 
 sub generate {
@@ -38,9 +39,15 @@ sub generate {
     last POST if $post_count > $post_limit;
   }
 
+  # XML::Feed (I suspect, really XML::Atom) plays silly buggers with the UTF-8
+  # flag...
+  my $xml_feed = $feed->as_xml;
+  utf8::decode($xml_feed)  # in place
+      or die "Unable to properly decode feed";
+
   my $feed_page = HiD::VirtualPage->new({
     output_filename => $site->destination . $destination ,
-    content         => $feed->as_xml ,
+    content         => $xml_feed ,
   });
 
   $site->add_input( "ATOM FEED" => 'page' );
@@ -52,18 +59,13 @@ sub generate {
 sub _new_entry {
   my( $self , $post ) = @_;
 
-  my $author = XML::Atom::Person->new();
-  $author->name($post->author);
-
-  my $link = XML::Atom::Link->new();
-  $link->type('text/html');
-  $link->rel('alternate');
-  $link->href($post->url);
-
-  my $entry = XML::Atom::Entry->new();
+  my $entry = XML::Feed::Entry->new('Atom');
   $entry->title($post->title);
-  $entry->author($author);
-  $entry->add_link($link);
+  $entry->author($post->author);
+  $entry->link($post->url);
+  $entry->id($post->baseurl . $post->url);
+  $entry->updated($post->date);
+  $entry->summary($post->description) if $post->description;
   $entry->content($post->converted_content);
 
   return $entry;
@@ -72,31 +74,19 @@ sub _new_entry {
 sub _new_feed {
   my( $self , $site ) = @_;
 
-  my $feed  = XML::Atom::Feed->new();
+  my $feed  = XML::Feed->new('Atom');
   my $title = $site->config->{atom_feed}{title} // $site->config->{title};
   $feed->title( $title );
 
-  if ( my $base_url = $site->config->{atom_feed}{base} ) {
-    my $base_link = XML::Atom::Link->new();
-    $base_link->type('text/html');
-    $base_link->rel('alternate');
-    $base_link->href($base_url);
+  $feed->base( $site->config->{atom_feed}{base} )
+    if $site->config->{atom_feed}{base};
 
-    $feed->add_link( $base_link );
+  if( $site->config->{atom_feed}{link}) {
+    $feed->link( $site->config->{atom_feed}{link} );
+    $feed->id( $site->config->{atom_feed}{link} );
   }
 
-  if ( my $feed_url = $site->config->{atom_feed}{link} ) {
-    my $feed_link = XML::Atom::Link->new();
-    $feed_link->type('application/atom+xml');
-    $feed_link->rel('self');
-    $feed_link->href( $feed_url );
-
-    $feed->add_link( $feed_link );
-
-    $feed->id( $feed_link );
-  }
-
-  $feed->updated(DateTime->now());
+  $feed->modified(DateTime->now());
 
   return $feed;
 }
@@ -173,7 +163,7 @@ See the documentation above to understand what each key controls.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
