@@ -2,22 +2,21 @@
 
 
 package HiD::Layout;
-$HiD::Layout::VERSION = '1.91';
+$HiD::Layout::VERSION = '1.95';
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use Encode;
-use File::Slurp qw/ read_file / ;
+use Path::Tiny;
+use YAML::Tiny  qw/ Load /;
+
 use HiD::Types;
-use YAML::XS;
 
 
 has content => (
@@ -81,14 +80,14 @@ sub BUILDARGS {
     ( $args{name} , $args{ext} ) = $args{filename}
       =~ m|^.*/(.+)\.([^.]+)$|;
 
-    my $content  = read_file( $args{filename}, binmode => ':utf8' );
+    my $content  = path( $args{filename} )->slurp_utf8;
     my $metadata = {};
 
     if ( $content =~ /^---\n/s ) {
       my $meta;
       ( $meta , $content ) = ( $content )
         =~ m|^---\n(.*?)---\n(.*)$|s;
-      $metadata = Load( encode('utf8', $meta) ) if $meta;
+      $metadata = Load( $meta ) if $meta;
     }
 
     $args{metadata} = $metadata;
@@ -203,7 +202,7 @@ Will recurse into embedded layouts as needed.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
