@@ -2,23 +2,20 @@
 
 
 package HiD::Page;
-$HiD::Page::VERSION = '1.91';
+$HiD::Page::VERSION = '1.95';
 use Moose;
 with 'HiD::Role::IsConverted';
 with 'HiD::Role::IsPublished';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename  qw/ fileparse /;
-use File::Path      qw/ make_path /;
-use Path::Class     qw/ file / ;
+use Path::Tiny;
 
 
 sub get_default_layout { 'default' }
@@ -27,13 +24,12 @@ sub get_default_layout { 'default' }
 sub publish {
   my $self = shift;
 
-  my( undef , $dir ) = fileparse( $self->output_filename );
+  my $out = path( $self->output_filename );
+  my $dir = $out->parent;
 
-  make_path $dir unless -d $dir;
+  $dir->mkpath unless $dir->is_dir;
 
-  open( my $out , '>:utf8' , $self->output_filename ) or die $!;
-  print $out $self->rendered_content;
-  close( $out );
+  $out->spew_utf8( $self->rendered_content );
 }
 
 # used to populate the 'url' attr in Role::IsPublished
@@ -43,10 +39,12 @@ sub _build_url {
   my $format = $self->get_metadata( 'permalink' ) // 'none';
 
   my $source = $self->source;
+
   my $path_frag = $self->input_path;
   $path_frag =~ s/^$source//;
+  $path_frag ||= Path::Tiny->rootdir();
 
-  my $naive = join '/' , $path_frag , $self->basename;
+  my $naive = path( $path_frag , $self->basename() );
 
   my %_valid_exts = map { $_=>1 } qw(rss xml html htm xhtml xhtm shtml shtm);
   my $ext = exists $_valid_exts{$self->ext} ? $self->ext : 'html';
@@ -109,7 +107,7 @@ object from this class works.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
