@@ -2,21 +2,19 @@
 
 
 package HiD::Pager;
-$HiD::Pager::VERSION = '1.91';
+$HiD::Pager::VERSION = '1.95';
 use Moose;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
-use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Data::Page;
 use String::Errf    qw/ errf /;
@@ -256,7 +254,7 @@ Returns the URL for the previous page in the set.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
