@@ -2,16 +2,15 @@
 
 
 package HiD::Plugin;
-$HiD::Plugin::VERSION = '1.91';
+$HiD::Plugin::VERSION = '1.95';
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
-use feature    qw/ unicode_strings /;
 
 
 sub after_publish { 1 }
@@ -43,7 +42,7 @@ Base class for plugin object
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
