@@ -2,18 +2,17 @@
 
 
 package HiD::Processor::Handlebars;
-$HiD::Processor::Handlebars::VERSION = '1.91';
+$HiD::Processor::Handlebars::VERSION = '1.95';
 use Moose;
 extends 'HiD::Processor';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014;  # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Text::Handlebars;
 
@@ -65,7 +64,7 @@ Wraps up a L<Text::Handlebars> object and allows it to be used during HiD public
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
