@@ -2,18 +2,17 @@
 
 
 package HiD::Processor::Template;
-$HiD::Processor::Template::VERSION = '1.91';
+$HiD::Processor::Template::VERSION = '1.95';
 use Moose;
 extends 'HiD::Processor';
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Template;
 
@@ -94,7 +93,7 @@ Display the template error message.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
