@@ -2,24 +2,23 @@
 
 
 package HiD::Role::IsConverted;
-$HiD::Role::IsConverted::VERSION = '1.91';
+$HiD::Role::IsConverted::VERSION = '1.95';
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Carp;
-use Class::Load  qw/ :all /;
-use Encode;
-use File::Slurp  qw/ read_file /;
+use Class::Load  qw/ load_class /;
+use Path::Tiny;
+use YAML::XS     qw/ Load /; # YAML::Tiny doesn't support 'bool' types which we need 8^/
+
 use HiD::Types;
-use YAML::XS     qw/ Load /;
 
 requires 'get_default_layout';
 
@@ -158,7 +157,7 @@ around BUILDARGS => sub {
   my %args = ( ref $_[0] and ref $_[0] eq 'HASH' ) ? %{ $_[0] } : @_;
 
   unless ( $args{content} and $args{metadata} ) {
-    my $file_content = read_file( $args{input_filename}, binmode => ':utf8' );
+    my $file_content = path( $args{input_filename} )->slurp_utf8;
 
     my( $metadata , $content );
     if ( $file_content =~ /^---/ ) {
@@ -174,7 +173,7 @@ around BUILDARGS => sub {
     }
 
     $args{content}  = $content;
-    $args{metadata} = Load( encode('utf8',$metadata) ) // {};
+    $args{metadata} = Load( $metadata ) // {};
   }
 
   return $class->$orig( \%args );
@@ -281,7 +280,7 @@ Data for passing to template processing function.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
