@@ -2,23 +2,21 @@
 
 
 package HiD::Role::IsPost;
-$HiD::Role::IsPost::VERSION = '1.91';
+$HiD::Role::IsPost::VERSION = '1.95';
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use DateTime;
 use Date::Parse    qw/ str2time  /;
-use File::Basename qw/ fileparse /;
+
 use HiD::Types;
-use YAML::XS;
 
 
 has author => (
@@ -292,7 +290,7 @@ folder or not.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
