@@ -2,21 +2,20 @@
 
 
 package HiD::Role::IsPublished;
-$HiD::Role::IsPublished::VERSION = '1.91';
+$HiD::Role::IsPublished::VERSION = '1.95';
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename  qw/ fileparse /;
+use Path::Tiny;
+
 use HiD::Types;
-use Path::Class     qw/ file /;
 
 requires 'publish';
 
@@ -31,7 +30,7 @@ has basename => (
 sub _build_basename {
   my $self = shift;
   my $ext = '.' . $self->ext;
-  return fileparse( $self->input_filename , $ext );
+  return path( $self->input_filename )->basename( $ext );
 }
 
 
@@ -45,11 +44,8 @@ has baseurl => (
 sub _build_baseurl {
   my $self = shift;
 
-  my $base_url = $self->config->{baseurl};
-  if( defined $base_url ) {
-    return $base_url;
-  }
-  return '/';
+  my $base_url = $self->get_config('baseurl');
+  return defined $base_url ? $base_url : '/';
 }
 
 
@@ -83,11 +79,7 @@ has input_path => (
   is      => 'ro' ,
   isa     => 'HiD_DirPath' ,
   lazy    => 1 ,
-  default => sub {
-    my $self = shift;
-    my( undef , $path ) = fileparse( $self->input_filename );
-    return $path;
-  },
+  default => sub { path( shift->input_filename )->parent->stringify() },
 );
 
 
@@ -101,7 +93,7 @@ has output_filename => (
     my $url = $self->url;
     $url .= 'index.html' if $url =~ m|/$|;
 
-    return file( $self->dest_dir , $url )->stringify;
+    return path( $self->dest_dir , $url )->stringify;
   },
 );
 
@@ -189,7 +181,7 @@ The URL to the output path for the written file.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
