@@ -2,8 +2,8 @@
 
 
 package HiD::Server;
-$HiD::Server::VERSION = '1.91';
-use strict;
+$HiD::Server::VERSION = '1.95';
+use 5.014; # strict, unicode_strings
 use warnings;
 
 use parent 'Plack::App::File';
@@ -52,7 +52,7 @@ Overrides L<Plack::App::File>'s method of the same name to handle '/' and
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
