@@ -2,8 +2,8 @@
 
 
 package HiD::Server::Handler;
-$HiD::Server::Handler::VERSION = '1.91';
-use strict;
+$HiD::Server::Handler::VERSION = '1.95';
+use 5.014;  # strict, unicode_strings
 use warnings;
 
 use parent 'Plack::Handler::Standalone';
@@ -14,7 +14,7 @@ sub new {
 
   my $hid = delete $args{hid};
 
-  die "I must be passed a HiD not a $hid!"
+  die "I must be passed something that can('publish') not a '$hid'!\n"
     unless defined $hid and $hid->can('publish');
 
   my $self = $class->SUPER::new(%args);
@@ -69,7 +69,7 @@ Helper for C<hid publish -A>
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
