@@ -2,8 +2,8 @@
 
 
 package HiD::Server::Loader;
-$HiD::Server::Loader::VERSION = '1.91';
-use strict;
+$HiD::Server::Loader::VERSION = '1.95';
+use 5.014;  # strict, unicode_strings
 use warnings;
 
 use parent 'Plack::Loader::Restarter';
@@ -47,7 +47,7 @@ Another helper for C<hid publish -A>
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
