@@ -2,16 +2,14 @@
 
 
 package HiD::Types;
-$HiD::Types::VERSION = '1.91';
-use 5.014;
+$HiD::Types::VERSION = '1.95';
+use 5.014; # strict, unicode_strings
 use utf8;
-use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
 use Moose::Util::TypeConstraints;
 
@@ -67,7 +65,7 @@ Type constraints for HiD.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
