@@ -2,32 +2,29 @@
 
 
 package HiD::VirtualPage;
-$HiD::VirtualPage::VERSION = '1.91';
+$HiD::VirtualPage::VERSION = '1.95';
 use Moose;
 use namespace::autoclean;
 
-use 5.014;
+use 5.014; # strict, unicode_strings
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-use feature     qw/ unicode_strings /;
 
-use File::Basename  qw/ fileparse /;
-use File::Path      qw/ make_path /;
-use Path::Class     qw/ file / ;
+use Path::Tiny;
 
 
 has output_filename => (
-  is => 'ro' ,
-  isa => 'Str' ,
+  is       => 'ro' ,
+  isa      => 'Str' ,
   required => 1 ,
 );
 
 has content => (
-  is => 'ro' ,
-  isa => 'Str' ,
+  is       => 'ro' ,
+  isa      => 'Str' ,
   required => 1 ,
 );
 
@@ -35,13 +32,12 @@ has content => (
 sub publish {
   my $self = shift;
 
-  my( undef , $dir ) = fileparse( $self->output_filename );
+  my $out = path( $self->output_filename );
+  my $dir = $out->parent;
 
-  make_path $dir unless -d $dir;
+  $dir->mkpath() unless $dir->is_dir;
 
-  open( my $out , '>:utf8' , $self->output_filename ) or die $!;
-  print $out $self->content;
-  close( $out );
+  $out->spew_utf8( $self->content );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -84,7 +80,7 @@ Publish -- write out to disk -- this data from this object.
 
 =head1 VERSION
 
-version 1.91
+version 1.95
 
 =head1 AUTHOR
 
